==> jbpm-polyglot-example-0.4.0-sources.jar: org/kogito/examples/polyglot/ApplicantprocessProcess.java <==
package org.kogito.examples.polyglot;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@javax.enterprise.context.ApplicationScoped()
@javax.inject.Named("applicantprocess")
public class ApplicantprocessProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kogito.examples.polyglot.ApplicantprocessModel> {

    @javax.inject.Inject()
    javax.enterprise.inject.Instance<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public ApplicantprocessProcess() {
    }

    @javax.inject.Inject()
    public ApplicantprocessProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(org.kogito.examples.polyglot.ApplicantprocessModel value) {
        return new org.kogito.examples.polyglot.ApplicantprocessProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.kogito.examples.polyglot.ApplicantprocessModel createModel() {
        return new org.kogito.examples.polyglot.ApplicantprocessModel();
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kogito.examples.polyglot.ApplicantprocessModel) value);
    }

    public ApplicantprocessProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("applicantprocess");
        factory.variable("applicant", new ObjectDataType("org.kie.kogito.examples.polyglot.Applicant"));
        factory.name("Sample Process");
        factory.packageName("org.kogito.examples.polyglot");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("Documentation", "Sample Process for Polyglot example");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        factory.imports("org.kie.kogito.examples.polyglot.Applicant");
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode1 = factory.startNode(1);
        startNode1.name("");
        startNode1.metaData("UniqueId", "_AD4EDA95-5900-4E8E-A2DC-CBEDB7206C47");
        startNode1.metaData("x", 117);
        startNode1.metaData("width", 30);
        startNode1.metaData("y", 137);
        startNode1.metaData("height", 30);
        startNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode2 = factory.actionNode(2);
        actionNode2.name("Dump applicant");
        actionNode2.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            System.out.println("jBPM Process - About to evaluate new applicant: " + applicant.toString());;
        });
        actionNode2.metaData("UniqueId", "_4DA1C3DB-E98D-4FA1-A63B-28E8F0F31EBC");
        actionNode2.metaData("elementname", "Dump applicant");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 225);
        actionNode2.metaData("width", 100);
        actionNode2.metaData("y", 112);
        actionNode2.metaData("height", 80);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.SplitFactory splitNode3 = factory.splitNode(3);
        splitNode3.name("");
        splitNode3.type(2);
        splitNode3.metaData("UniqueId", "_A6E460DD-7665-4CD7-9C71-5A19C98DB45B");
        splitNode3.metaData("x", 360);
        splitNode3.metaData("width", 40);
        splitNode3.metaData("y", 132);
        splitNode3.metaData("Default", "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06");
        splitNode3.metaData("height", 40);
        splitNode3.constraint(5, "_5989C45B-B132-4247-B24C-CDB5862660B0", "DROOLS_DEFAULT", "java", kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            {
                return applicant.getAge() < 18;
            }
        }, 0);
        splitNode3.constraint(4, "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06", "DROOLS_DEFAULT", "java", kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            {
                return applicant.getAge() >= 18;
            }
        }, 0);
        splitNode3.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode4 = factory.actionNode(4);
        actionNode4.name("validate1");
        actionNode4.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            applicant.setValid( true );;
        });
        actionNode4.metaData("UniqueId", "_E2A8593C-E53F-4474-88EF-7BC8EC2267F6");
        actionNode4.metaData("elementname", "validate1");
        actionNode4.metaData("NodeType", "ScriptTask");
        actionNode4.metaData("x", 455);
        actionNode4.metaData("width", 100);
        actionNode4.metaData("y", 15);
        actionNode4.metaData("height", 80);
        actionNode4.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode5 = factory.actionNode(5);
        actionNode5.name("validate2");
        actionNode5.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            applicant.setValid( false );;
        });
        actionNode5.metaData("UniqueId", "_A83C7491-337F-46F7-BB2D-079BCA7E53F0");
        actionNode5.metaData("elementname", "validate2");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 455);
        actionNode5.metaData("width", 100);
        actionNode5.metaData("y", 210);
        actionNode5.metaData("height", 80);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode6 = factory.endNode(6);
        endNode6.name("");
        endNode6.terminate(false);
        endNode6.metaData("UniqueId", "_C58EC543-FE53-4565-B1AB-05930CE12AB0");
        endNode6.metaData("x", 600);
        endNode6.metaData("width", 28);
        endNode6.metaData("y", 41);
        endNode6.metaData("height", 28);
        endNode6.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode7 = factory.endNode(7);
        endNode7.name("");
        endNode7.terminate(false);
        endNode7.metaData("UniqueId", "_453B335D-EAE2-430D-B0C3-EAF1B9772662");
        endNode7.metaData("x", 600);
        endNode7.metaData("width", 28);
        endNode7.metaData("y", 236);
        endNode7.metaData("height", 28);
        endNode7.done();
        factory.connection(1, 2, "_4A6A7CBB-0736-47D8-8EEA-A21B62365FED");
        factory.connection(2, 3, "_D8090C93-2BE4-4C4D-9294-D35A6EE7C80D");
        factory.connection(3, 4, "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06");
        factory.connection(3, 5, "_5989C45B-B132-4247-B24C-CDB5862660B0");
        factory.connection(4, 6, "_A80F3E6B-95DA-4403-992F-741B4FB0B44A");
        factory.connection(5, 7, "_7B3DF017-E1B0-4729-8B23-17710530692D");
        factory.validate();
        return factory.getProcess();
    }

    public void init(@javax.enterprise.event.Observes() io.quarkus.runtime.StartupEvent event) {
        this.configure();
    }
}

==> jbpm-polyglot-example-0.8.1-sources.jar: org/kogito/examples/polyglot/ApplicantprocessProcess.java <==
package org.kogito.examples.polyglot;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@javax.enterprise.context.ApplicationScoped()
@javax.inject.Named("applicantprocess")
public class ApplicantprocessProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kogito.examples.polyglot.ApplicantprocessModel> {

    @javax.inject.Inject()
    javax.enterprise.inject.Instance<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public ApplicantprocessProcess() {
    }

    @javax.inject.Inject()
    public ApplicantprocessProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(org.kogito.examples.polyglot.ApplicantprocessModel value) {
        return new org.kogito.examples.polyglot.ApplicantprocessProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(java.lang.String businessKey, org.kogito.examples.polyglot.ApplicantprocessModel value) {
        return new org.kogito.examples.polyglot.ApplicantprocessProcessInstance(this, value, businessKey, this.createLegacyProcessRuntime());
    }

    public org.kogito.examples.polyglot.ApplicantprocessModel createModel() {
        return new org.kogito.examples.polyglot.ApplicantprocessModel();
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kogito.examples.polyglot.ApplicantprocessModel) value);
    }

    public org.kogito.examples.polyglot.ApplicantprocessProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.kogito.examples.polyglot.ApplicantprocessModel) value);
    }

    public ApplicantprocessProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("applicantprocess");
        factory.variable("applicant", new ObjectDataType("org.kie.kogito.examples.polyglot.Applicant"), "customTags", null);
        factory.name("Sample Process");
        factory.packageName("org.kogito.examples.polyglot");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("Documentation", "Sample Process for Polyglot example");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        factory.imports("org.kie.kogito.examples.polyglot.Applicant");
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode1 = factory.startNode(1);
        startNode1.name("");
        startNode1.interrupting(true);
        startNode1.metaData("UniqueId", "_AD4EDA95-5900-4E8E-A2DC-CBEDB7206C47");
        startNode1.metaData("x", 117);
        startNode1.metaData("width", 30);
        startNode1.metaData("y", 137);
        startNode1.metaData("height", 30);
        startNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode2 = factory.actionNode(2);
        actionNode2.name("Dump applicant");
        actionNode2.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            System.out.println("jBPM Process - About to evaluate new applicant: " + applicant.toString());;
        });
        actionNode2.metaData("UniqueId", "_4DA1C3DB-E98D-4FA1-A63B-28E8F0F31EBC");
        actionNode2.metaData("elementname", "Dump applicant");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 225);
        actionNode2.metaData("width", 100);
        actionNode2.metaData("y", 112);
        actionNode2.metaData("height", 80);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.SplitFactory splitNode3 = factory.splitNode(3);
        splitNode3.name("");
        splitNode3.type(2);
        splitNode3.metaData("UniqueId", "_A6E460DD-7665-4CD7-9C71-5A19C98DB45B");
        splitNode3.metaData("x", 360);
        splitNode3.metaData("width", 40);
        splitNode3.metaData("y", 132);
        splitNode3.metaData("Default", "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06");
        splitNode3.metaData("height", 40);
        splitNode3.constraint(5, "_5989C45B-B132-4247-B24C-CDB5862660B0", "DROOLS_DEFAULT", "java", kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            {
                return applicant.getAge() < 18;
            }
        }, 0);
        splitNode3.constraint(4, "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06", "DROOLS_DEFAULT", "java", kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            {
                return applicant.getAge() >= 18;
            }
        }, 0);
        splitNode3.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode4 = factory.actionNode(4);
        actionNode4.name("validate1");
        actionNode4.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            applicant.setValid( true );;
        });
        actionNode4.metaData("UniqueId", "_E2A8593C-E53F-4474-88EF-7BC8EC2267F6");
        actionNode4.metaData("elementname", "validate1");
        actionNode4.metaData("NodeType", "ScriptTask");
        actionNode4.metaData("x", 455);
        actionNode4.metaData("width", 100);
        actionNode4.metaData("y", 15);
        actionNode4.metaData("height", 80);
        actionNode4.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory actionNode5 = factory.actionNode(5);
        actionNode5.name("validate2");
        actionNode5.action(kcontext -> {
            org.kie.kogito.examples.polyglot.Applicant applicant = (org.kie.kogito.examples.polyglot.Applicant) kcontext.getVariable("applicant");
            applicant.setValid( false );;
        });
        actionNode5.metaData("UniqueId", "_A83C7491-337F-46F7-BB2D-079BCA7E53F0");
        actionNode5.metaData("elementname", "validate2");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 455);
        actionNode5.metaData("width", 100);
        actionNode5.metaData("y", 210);
        actionNode5.metaData("height", 80);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode6 = factory.endNode(6);
        endNode6.name("");
        endNode6.terminate(false);
        endNode6.metaData("UniqueId", "_C58EC543-FE53-4565-B1AB-05930CE12AB0");
        endNode6.metaData("x", 600);
        endNode6.metaData("width", 28);
        endNode6.metaData("y", 41);
        endNode6.metaData("height", 28);
        endNode6.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode7 = factory.endNode(7);
        endNode7.name("");
        endNode7.terminate(false);
        endNode7.metaData("UniqueId", "_453B335D-EAE2-430D-B0C3-EAF1B9772662");
        endNode7.metaData("x", 600);
        endNode7.metaData("width", 28);
        endNode7.metaData("y", 236);
        endNode7.metaData("height", 28);
        endNode7.done();
        factory.connection(1, 2, "_4A6A7CBB-0736-47D8-8EEA-A21B62365FED");
        factory.connection(2, 3, "_D8090C93-2BE4-4C4D-9294-D35A6EE7C80D");
        factory.connection(3, 4, "_6E68206E-356B-4F46-BDA9-ABFD44CBFC06");
        factory.connection(3, 5, "_5989C45B-B132-4247-B24C-CDB5862660B0");
        factory.connection(4, 6, "_A80F3E6B-95DA-4403-992F-741B4FB0B44A");
        factory.connection(5, 7, "_7B3DF017-E1B0-4729-8B23-17710530692D");
        factory.validate();
        return factory.getProcess();
    }

    public void init(@javax.enterprise.event.Observes() io.quarkus.runtime.StartupEvent event) {
        this.configure();
    }
}
